<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru" sourcelanguage="en">
<context>
    <name>OptionsWidget</name>
    <message>
        <location filename="../../OptionsWidget.ui" line="17"/>
        <source>In normal case, only the dll 64Bits is important with 64Bits OS, and 32Bits dll with 32Bits OS. When it&apos;s important, the UAC can be opened to load the dll.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../OptionsWidget.ui" line="20"/>
        <source>All the dlls are importants</source>
        <translation>Все библиотеки являются важным</translation>
    </message>
    <message>
        <location filename="../../OptionsWidget.ui" line="34"/>
        <source>Register for all users</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
